@@ -30,6 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdbool.h>
 
 #ifndef PACKAGE
 #error "Please include config.h before including this file!"
@@ -176,21 +177,6 @@ static inline size_t PA_PAGE_ALIGN(size_t l) {
 #define PA_CLIP_SUB(a, b) ((a) > (b) ? (a) - (b) : 0)
 #endif
 
-/* This type is not intended to be used in exported APIs! Use classic "int" there! */
-#ifdef HAVE_STD_BOOL
-typedef _Bool pa_bool_t;
-#else
-typedef int pa_bool_t;
-#endif
-
-#ifndef FALSE
-#define FALSE ((pa_bool_t) 0)
-#endif
-
-#ifndef TRUE
-#define TRUE (!FALSE)
-#endif
-
 #ifdef __GNUC__
 #define PA_PRETTY_FUNCTION __PRETTY_FUNCTION__
 #else
@@ -203,7 +189,7 @@ typedef int pa_bool_t;
             pa_log_debug("Assertion '%s' failed at %s:%u, function %s.\n", #expr , __FILE__, __LINE__, PA_PRETTY_FUNCTION); \
             return;                                                     \
         }                                                               \
-    } while(FALSE)
+    } while(false)
 
 #define pa_return_val_if_fail(expr, val)                                \
     do {                                                                \
@@ -211,7 +197,7 @@ typedef int pa_bool_t;
             pa_log_debug("Assertion '%s' failed at %s:%u, function %s.\n", #expr , __FILE__, __LINE__, PA_PRETTY_FUNCTION); \
             return (val);                                               \
         }                                                               \
-    } while(FALSE)
+    } while(false)
 
 #define pa_return_null_if_fail(expr) pa_return_val_if_fail(expr, NULL)
 
@@ -223,10 +209,10 @@ typedef int pa_bool_t;
             pa_log_error("Assertion '%s' failed at %s:%u, function %s(). Aborting.", #expr , __FILE__, __LINE__, PA_PRETTY_FUNCTION); \
             abort();                                                    \
         }                                                               \
-    } while (FALSE)
+    } while (false)
 
 /* Does exactly nothing */
-#define pa_nop() do {} while (FALSE)
+#define pa_nop() do {} while (false)
 
 /* pa_assert() is an assert that may be optimized away by defining
  * NDEBUG. pa_assert_fp() is an assert that may be optimized away by
@@ -251,7 +237,7 @@ typedef int pa_bool_t;
     do {                                                                \
         pa_log_error("Code should not be reached at %s:%u, function %s(). Aborting.", __FILE__, __LINE__, PA_PRETTY_FUNCTION); \
         abort();                                                        \
-    } while (FALSE)
+    } while (false)
 #endif
 
 /* A compile time assertion */
@@ -262,7 +248,7 @@ typedef int pa_bool_t;
             case !!(expr):                         \
                 ;                                  \
         }                                          \
-    } while (FALSE)
+    } while (false)
 
 #define PA_PTR_TO_UINT(p) ((unsigned int) ((uintptr_t) (p)))
 #define PA_UINT_TO_PTR(u) ((void*) ((uintptr_t) (u)))
